Class: Knievel::AdvertisersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/knievel/api/advertisers_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AdvertisersApi

Returns a new instance of AdvertisersApi.



19
20
21
# File 'lib/knievel/api/advertisers_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/knievel/api/advertisers_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#batch_upsert_advertisers(project_id, batch_upsert_advertisers_request, opts = {}) ⇒ BatchUpsertAdvertisersResult

‘POST /v1/projects/:project_id/advertisers:batchUpsert` — bulk by `externalId`. Single Postgres transaction; per `API.md` "Write contract" any per-row failure rolls back the whole batch with `details[]` listing every offending row. On success: 200 with the upserted rows in input order.

Parameters:

Returns:



27
28
29
30
# File 'lib/knievel/api/advertisers_api.rb', line 27

def batch_upsert_advertisers(project_id, batch_upsert_advertisers_request, opts = {})
  data, _status_code, _headers = batch_upsert_advertisers_with_http_info(project_id, batch_upsert_advertisers_request, opts)
  data
end

#batch_upsert_advertisers_with_http_info(project_id, batch_upsert_advertisers_request, opts = {}) ⇒ Array<(BatchUpsertAdvertisersResult, Integer, Hash)>

&#x60;POST /v1/projects/:project_id/advertisers:batchUpsert&#x60; — bulk by &#x60;externalId&#x60;. Single Postgres transaction; per &#x60;API.md&#x60; &quot;Write contract&quot; any per-row failure rolls back the whole batch with &#x60;details[]&#x60; listing every offending row. On success: 200 with the upserted rows in input order.

Parameters:

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/knievel/api/advertisers_api.rb', line 37

def batch_upsert_advertisers_with_http_info(project_id, batch_upsert_advertisers_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdvertisersApi.batch_upsert_advertisers ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling AdvertisersApi.batch_upsert_advertisers"
  end
  # verify the required parameter 'batch_upsert_advertisers_request' is set
  if @api_client.config.client_side_validation && batch_upsert_advertisers_request.nil?
    fail ArgumentError, "Missing the required parameter 'batch_upsert_advertisers_request' when calling AdvertisersApi.batch_upsert_advertisers"
  end
  # resource path
  local_var_path = '/v1/projects/{project_id}/advertisers:batchUpsert'.sub('{project_id}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json; charset=utf-8'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(batch_upsert_advertisers_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BatchUpsertAdvertisersResult'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"AdvertisersApi.batch_upsert_advertisers",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdvertisersApi#batch_upsert_advertisers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_advertiser(project_id, create_advertiser_request, opts = {}) ⇒ Advertiser

Parameters:

  • project_id (String)
  • create_advertiser_request (CreateAdvertiserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



98
99
100
101
# File 'lib/knievel/api/advertisers_api.rb', line 98

def create_advertiser(project_id, create_advertiser_request, opts = {})
  data, _status_code, _headers = create_advertiser_with_http_info(project_id, create_advertiser_request, opts)
  data
end

#create_advertiser_with_http_info(project_id, create_advertiser_request, opts = {}) ⇒ Array<(Advertiser, Integer, Hash)>

Returns Advertiser data, response status code and response headers.

Parameters:

  • project_id (String)
  • create_advertiser_request (CreateAdvertiserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Advertiser, Integer, Hash)>)

    Advertiser data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/knievel/api/advertisers_api.rb', line 107

def create_advertiser_with_http_info(project_id, create_advertiser_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdvertisersApi.create_advertiser ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling AdvertisersApi.create_advertiser"
  end
  # verify the required parameter 'create_advertiser_request' is set
  if @api_client.config.client_side_validation && create_advertiser_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_advertiser_request' when calling AdvertisersApi.create_advertiser"
  end
  # resource path
  local_var_path = '/v1/projects/{project_id}/advertisers'.sub('{project_id}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json; charset=utf-8'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_advertiser_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Advertiser'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"AdvertisersApi.create_advertiser",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdvertisersApi#create_advertiser\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_advertiser(project_id, id, opts = {}) ⇒ Advertiser

Parameters:

  • project_id (String)
  • id (Integer)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



168
169
170
171
# File 'lib/knievel/api/advertisers_api.rb', line 168

def get_advertiser(project_id, id, opts = {})
  data, _status_code, _headers = get_advertiser_with_http_info(project_id, id, opts)
  data
end

#get_advertiser_with_http_info(project_id, id, opts = {}) ⇒ Array<(Advertiser, Integer, Hash)>

Returns Advertiser data, response status code and response headers.

Parameters:

  • project_id (String)
  • id (Integer)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Advertiser, Integer, Hash)>)

    Advertiser data, response status code and response headers



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/knievel/api/advertisers_api.rb', line 177

def get_advertiser_with_http_info(project_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdvertisersApi.get_advertiser ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling AdvertisersApi.get_advertiser"
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling AdvertisersApi.get_advertiser"
  end
  # resource path
  local_var_path = '/v1/projects/{project_id}/advertisers/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Advertiser'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"AdvertisersApi.get_advertiser",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdvertisersApi#get_advertiser\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_advertisers(project_id, opts = {}) ⇒ AdvertiserList

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)
  • :cursor (String)

Returns:



234
235
236
237
# File 'lib/knievel/api/advertisers_api.rb', line 234

def list_advertisers(project_id, opts = {})
  data, _status_code, _headers = list_advertisers_with_http_info(project_id, opts)
  data
end

#list_advertisers_with_http_info(project_id, opts = {}) ⇒ Array<(AdvertiserList, Integer, Hash)>

Returns AdvertiserList data, response status code and response headers.

Parameters:

  • project_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)
  • :cursor (String)

Returns:

  • (Array<(AdvertiserList, Integer, Hash)>)

    AdvertiserList data, response status code and response headers



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/knievel/api/advertisers_api.rb', line 244

def list_advertisers_with_http_info(project_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdvertisersApi.list_advertisers ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling AdvertisersApi.list_advertisers"
  end
  # resource path
  local_var_path = '/v1/projects/{project_id}/advertisers'.sub('{project_id}', CGI.escape(project_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AdvertiserList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"AdvertisersApi.list_advertisers",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdvertisersApi#list_advertisers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_advertiser(project_id, id, update_advertiser_request, opts = {}) ⇒ Advertiser

Parameters:

  • project_id (String)
  • id (Integer)
  • update_advertiser_request (UpdateAdvertiserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



299
300
301
302
# File 'lib/knievel/api/advertisers_api.rb', line 299

def update_advertiser(project_id, id, update_advertiser_request, opts = {})
  data, _status_code, _headers = update_advertiser_with_http_info(project_id, id, update_advertiser_request, opts)
  data
end

#update_advertiser_with_http_info(project_id, id, update_advertiser_request, opts = {}) ⇒ Array<(Advertiser, Integer, Hash)>

Returns Advertiser data, response status code and response headers.

Parameters:

  • project_id (String)
  • id (Integer)
  • update_advertiser_request (UpdateAdvertiserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Advertiser, Integer, Hash)>)

    Advertiser data, response status code and response headers



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/knievel/api/advertisers_api.rb', line 309

def update_advertiser_with_http_info(project_id, id, update_advertiser_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdvertisersApi.update_advertiser ...'
  end
  # verify the required parameter 'project_id' is set
  if @api_client.config.client_side_validation && project_id.nil?
    fail ArgumentError, "Missing the required parameter 'project_id' when calling AdvertisersApi.update_advertiser"
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling AdvertisersApi.update_advertiser"
  end
  # verify the required parameter 'update_advertiser_request' is set
  if @api_client.config.client_side_validation && update_advertiser_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_advertiser_request' when calling AdvertisersApi.update_advertiser"
  end
  # resource path
  local_var_path = '/v1/projects/{project_id}/advertisers/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json; charset=utf-8'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_advertiser_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Advertiser'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"AdvertisersApi.update_advertiser",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdvertisersApi#update_advertiser\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end