Class: Knievel::CreateAdLibraryItemRequest

Inherits:
ApiModelBase show all
Defined in:
lib/knievel/models/create_ad_library_item_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAdLibraryItemRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::CreateAdLibraryItemRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::CreateAdLibraryItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'alt')
    self.alt = attributes[:'alt']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'values')
    self.values = attributes[:'values']
  end

  if attributes.key?(:'click_through_url')
    self.click_through_url = attributes[:'click_through_url']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end
end

Instance Attribute Details

#altObject

Returns the value of attribute alt.



30
31
32
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 30

def alt
  @alt
end

#bodyObject

Returns the value of attribute body.



32
33
34
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 32

def body
  @body
end

#click_through_urlObject

Returns the value of attribute click_through_url.



38
39
40
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 38

def click_through_url
  @click_through_url
end

#external_idObject

Returns the value of attribute external_id.



18
19
20
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 18

def external_id
  @external_id
end

#heightObject

Returns the value of attribute height.



28
29
30
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 28

def height
  @height
end

#image_urlObject

Returns the value of attribute image_url.



24
25
26
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 24

def image_url
  @image_url
end

#is_activeObject

Returns the value of attribute is_active.



40
41
42
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 40

def is_active
  @is_active
end

#kindObject

Returns the value of attribute kind.



22
23
24
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 22

def kind
  @kind
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 20

def name
  @name
end

#template_idObject

Returns the value of attribute template_id.



34
35
36
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 34

def template_id
  @template_id
end

#valuesObject

Returns the value of attribute values.



36
37
38
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 36

def values
  @values
end

#widthObject

Returns the value of attribute width.



26
27
28
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 26

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 43

def self.attribute_map
  {
    :'external_id' => :'external_id',
    :'name' => :'name',
    :'kind' => :'kind',
    :'image_url' => :'image_url',
    :'width' => :'width',
    :'height' => :'height',
    :'alt' => :'alt',
    :'body' => :'body',
    :'template_id' => :'template_id',
    :'values' => :'values',
    :'click_through_url' => :'click_through_url',
    :'is_active' => :'is_active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
93
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 89

def self.openapi_nullable
  Set.new([
    :'values',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 71

def self.openapi_types
  {
    :'external_id' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'image_url' => :'String',
    :'width' => :'Integer',
    :'height' => :'Integer',
    :'alt' => :'String',
    :'body' => :'String',
    :'template_id' => :'Integer',
    :'values' => :'Object',
    :'click_through_url' => :'String',
    :'is_active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_id == o.external_id &&
      name == o.name &&
      kind == o.kind &&
      image_url == o.image_url &&
      width == o.width &&
      height == o.height &&
      alt == o.alt &&
      body == o.body &&
      template_id == o.template_id &&
      values == o.values &&
      click_through_url == o.click_through_url &&
      is_active == o.is_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 236

def hash
  [external_id, name, kind, image_url, width, height, alt, body, template_id, values, click_through_url, is_active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
# File 'lib/knievel/models/create_ad_library_item_request.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @kind.nil?
  true
end