Class: Knievel::CreateCreativeTemplateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::CreateCreativeTemplateRequest
- Defined in:
- lib/knievel/models/create_creative_template_request.rb
Instance Attribute Summary collapse
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#schema ⇒ Object
Arbitrary JSON Schema document; not parsed by knievel.
-
#template ⇒ Object
Optional renderer source (today: Liquid).
-
#template_engine ⇒ Object
Returns the value of attribute template_engine.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCreativeTemplateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCreativeTemplateRequest
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::CreateCreativeTemplateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::CreateCreativeTemplateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'schema') self.schema = attributes[:'schema'] else self.schema = nil end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'template_engine') self.template_engine = attributes[:'template_engine'] end end |
Instance Attribute Details
#external_id ⇒ Object
Returns the value of attribute external_id.
18 19 20 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 18 def external_id @external_id end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 20 def name @name end |
#schema ⇒ Object
Arbitrary JSON Schema document; not parsed by knievel.
23 24 25 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 23 def schema @schema end |
#template ⇒ Object
Optional renderer source (today: Liquid). When present, ‘template_engine` MUST also be present and equal to `"liquid"`. Parsed at write time; malformed source returns `422 / template_parse_error`. Templates without a source are input-validation-only — only `native` creatives can reference them.
26 27 28 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 26 def template @template end |
#template_engine ⇒ Object
Returns the value of attribute template_engine.
28 29 30 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 28 def template_engine @template_engine end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 31 def self.attribute_map { :'external_id' => :'external_id', :'name' => :'name', :'schema' => :'schema', :'template' => :'template', :'template_engine' => :'template_engine' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
63 64 65 66 67 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 63 def self.openapi_nullable Set.new([ :'schema', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 52 def self.openapi_types { :'external_id' => :'String', :'name' => :'String', :'schema' => :'Object', :'template' => :'String', :'template_engine' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && external_id == o.external_id && name == o.name && schema == o.schema && template == o.template && template_engine == o.template_engine end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 160 def hash [external_id, name, schema, template, template_engine].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 |
# File 'lib/knievel/models/create_creative_template_request.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |