Class: Knievel::CreateSiteRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::CreateSiteRequest
- Defined in:
- lib/knievel/models/create_site_request.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Object
Returns the value of attribute aliases.
-
#channel_id ⇒ Object
Returns the value of attribute channel_id.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSiteRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateSiteRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/knievel/models/create_site_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::CreateSiteRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::CreateSiteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'channel_id') self.channel_id = attributes[:'channel_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'aliases') if (value = attributes[:'aliases']).is_a?(Array) self.aliases = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#aliases ⇒ Object
Returns the value of attribute aliases.
26 27 28 |
# File 'lib/knievel/models/create_site_request.rb', line 26 def aliases @aliases end |
#channel_id ⇒ Object
Returns the value of attribute channel_id.
20 21 22 |
# File 'lib/knievel/models/create_site_request.rb', line 20 def channel_id @channel_id end |
#external_id ⇒ Object
Returns the value of attribute external_id.
18 19 20 |
# File 'lib/knievel/models/create_site_request.rb', line 18 def external_id @external_id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
28 29 30 |
# File 'lib/knievel/models/create_site_request.rb', line 28 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/knievel/models/create_site_request.rb', line 22 def name @name end |
#url ⇒ Object
Returns the value of attribute url.
24 25 26 |
# File 'lib/knievel/models/create_site_request.rb', line 24 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/knievel/models/create_site_request.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/knievel/models/create_site_request.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/knievel/models/create_site_request.rb', line 31 def self.attribute_map { :'external_id' => :'external_id', :'channel_id' => :'channel_id', :'name' => :'name', :'url' => :'url', :'aliases' => :'aliases', :'is_active' => :'is_active' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/knievel/models/create_site_request.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/knievel/models/create_site_request.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/knievel/models/create_site_request.rb', line 53 def self.openapi_types { :'external_id' => :'String', :'channel_id' => :'Integer', :'name' => :'String', :'url' => :'String', :'aliases' => :'Array<String>', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/knievel/models/create_site_request.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && external_id == o.external_id && channel_id == o.channel_id && name == o.name && url == o.url && aliases == o.aliases && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/knievel/models/create_site_request.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/knievel/models/create_site_request.rb', line 183 def hash [external_id, channel_id, name, url, aliases, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/knievel/models/create_site_request.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/knievel/models/create_site_request.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 |
# File 'lib/knievel/models/create_site_request.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @url.nil? true end |