Class: Knievel::CreativeTemplate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::CreativeTemplate
- Defined in:
- lib/knievel/models/creative_template.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#etag ⇒ Object
Returns the value of attribute etag.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#template ⇒ Object
Returns the value of attribute template.
-
#template_engine ⇒ Object
Returns the value of attribute template_engine.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreativeTemplate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreativeTemplate
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/knievel/models/creative_template.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::CreativeTemplate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::CreativeTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'schema') self.schema = attributes[:'schema'] else self.schema = nil end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'template_engine') self.template_engine = attributes[:'template_engine'] end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'etag') self.etag = attributes[:'etag'] else self.etag = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/knievel/models/creative_template.rb', line 34 def created_at @created_at end |
#etag ⇒ Object
Returns the value of attribute etag.
32 33 34 |
# File 'lib/knievel/models/creative_template.rb', line 32 def etag @etag end |
#external_id ⇒ Object
Returns the value of attribute external_id.
20 21 22 |
# File 'lib/knievel/models/creative_template.rb', line 20 def external_id @external_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/knievel/models/creative_template.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/knievel/models/creative_template.rb', line 22 def name @name end |
#schema ⇒ Object
Returns the value of attribute schema.
24 25 26 |
# File 'lib/knievel/models/creative_template.rb', line 24 def schema @schema end |
#template ⇒ Object
Returns the value of attribute template.
26 27 28 |
# File 'lib/knievel/models/creative_template.rb', line 26 def template @template end |
#template_engine ⇒ Object
Returns the value of attribute template_engine.
28 29 30 |
# File 'lib/knievel/models/creative_template.rb', line 28 def template_engine @template_engine end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/knievel/models/creative_template.rb', line 36 def updated_at @updated_at end |
#version ⇒ Object
Returns the value of attribute version.
30 31 32 |
# File 'lib/knievel/models/creative_template.rb', line 30 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/knievel/models/creative_template.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/knievel/models/creative_template.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/knievel/models/creative_template.rb', line 39 def self.attribute_map { :'id' => :'id', :'external_id' => :'external_id', :'name' => :'name', :'schema' => :'schema', :'template' => :'template', :'template_engine' => :'template_engine', :'version' => :'version', :'etag' => :'etag', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/knievel/models/creative_template.rb', line 295 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 |
# File 'lib/knievel/models/creative_template.rb', line 81 def self.openapi_nullable Set.new([ :'schema', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/knievel/models/creative_template.rb', line 65 def self.openapi_types { :'id' => :'Integer', :'external_id' => :'String', :'name' => :'String', :'schema' => :'Object', :'template' => :'String', :'template_engine' => :'String', :'version' => :'Integer', :'etag' => :'String', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/knievel/models/creative_template.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && external_id == o.external_id && name == o.name && schema == o.schema && template == o.template && template_engine == o.template_engine && version == o.version && etag == o.etag && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
282 283 284 |
# File 'lib/knievel/models/creative_template.rb', line 282 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
288 289 290 |
# File 'lib/knievel/models/creative_template.rb', line 288 def hash [id, external_id, name, schema, template, template_engine, version, etag, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/knievel/models/creative_template.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @etag.nil? invalid_properties.push('invalid value for "etag", etag cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/knievel/models/creative_template.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/knievel/models/creative_template.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @version.nil? return false if @etag.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |