Class: Knievel::CreativeTemplatesApi
- Inherits:
-
Object
- Object
- Knievel::CreativeTemplatesApi
- Defined in:
- lib/knievel/api/creative_templates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
- #create_creative_template(project_id, create_creative_template_request, opts = {}) ⇒ CreativeTemplate
-
#create_creative_template_with_http_info(project_id, create_creative_template_request, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
CreativeTemplate data, response status code and response headers.
- #get_creative_template(project_id, id, opts = {}) ⇒ CreativeTemplate
-
#get_creative_template_with_http_info(project_id, id, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
CreativeTemplate data, response status code and response headers.
-
#initialize(api_client = ApiClient.default) ⇒ CreativeTemplatesApi
constructor
A new instance of CreativeTemplatesApi.
- #list_creative_templates(project_id, opts = {}) ⇒ CreativeTemplateList
-
#list_creative_templates_with_http_info(project_id, opts = {}) ⇒ Array<(CreativeTemplateList, Integer, Hash)>
CreativeTemplateList data, response status code and response headers.
-
#update_creative_template(project_id, id, update_creative_template_request, opts = {}) ⇒ CreativeTemplate
PATCH bumps ‘version` whenever the schema field is provided (per `API.md`  3.6 — schema changes are versioned but do not retroactively re-validate existing creatives).
-
#update_creative_template_with_http_info(project_id, id, update_creative_template_request, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
PATCH bumps `version` whenever the schema field is provided (per `API.md`  3.6 — schema changes are versioned but do not retroactively re-validate existing creatives).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CreativeTemplatesApi
Returns a new instance of CreativeTemplatesApi.
19 20 21 |
# File 'lib/knievel/api/creative_templates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/knievel/api/creative_templates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_creative_template(project_id, create_creative_template_request, opts = {}) ⇒ CreativeTemplate
26 27 28 29 |
# File 'lib/knievel/api/creative_templates_api.rb', line 26 def create_creative_template(project_id, create_creative_template_request, opts = {}) data, _status_code, _headers = create_creative_template_with_http_info(project_id, create_creative_template_request, opts) data end |
#create_creative_template_with_http_info(project_id, create_creative_template_request, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
Returns CreativeTemplate data, response status code and response headers.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/knievel/api/creative_templates_api.rb', line 35 def create_creative_template_with_http_info(project_id, create_creative_template_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativeTemplatesApi.create_creative_template ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CreativeTemplatesApi.create_creative_template" end # verify the required parameter 'create_creative_template_request' is set if @api_client.config.client_side_validation && create_creative_template_request.nil? fail ArgumentError, "Missing the required parameter 'create_creative_template_request' when calling CreativeTemplatesApi.create_creative_template" end # resource path local_var_path = '/v1/projects/{project_id}/creative-templates'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_creative_template_request) # return_type return_type = opts[:debug_return_type] || 'CreativeTemplate' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"CreativeTemplatesApi.create_creative_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativeTemplatesApi#create_creative_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_creative_template(project_id, id, opts = {}) ⇒ CreativeTemplate
96 97 98 99 |
# File 'lib/knievel/api/creative_templates_api.rb', line 96 def get_creative_template(project_id, id, opts = {}) data, _status_code, _headers = get_creative_template_with_http_info(project_id, id, opts) data end |
#get_creative_template_with_http_info(project_id, id, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
Returns CreativeTemplate data, response status code and response headers.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/knievel/api/creative_templates_api.rb', line 105 def get_creative_template_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativeTemplatesApi.get_creative_template ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CreativeTemplatesApi.get_creative_template" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CreativeTemplatesApi.get_creative_template" end # resource path local_var_path = '/v1/projects/{project_id}/creative-templates/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CreativeTemplate' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"CreativeTemplatesApi.get_creative_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativeTemplatesApi#get_creative_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_creative_templates(project_id, opts = {}) ⇒ CreativeTemplateList
162 163 164 165 |
# File 'lib/knievel/api/creative_templates_api.rb', line 162 def list_creative_templates(project_id, opts = {}) data, _status_code, _headers = list_creative_templates_with_http_info(project_id, opts) data end |
#list_creative_templates_with_http_info(project_id, opts = {}) ⇒ Array<(CreativeTemplateList, Integer, Hash)>
Returns CreativeTemplateList data, response status code and response headers.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/knievel/api/creative_templates_api.rb', line 172 def list_creative_templates_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativeTemplatesApi.list_creative_templates ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CreativeTemplatesApi.list_creative_templates" end # resource path local_var_path = '/v1/projects/{project_id}/creative-templates'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CreativeTemplateList' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"CreativeTemplatesApi.list_creative_templates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativeTemplatesApi#list_creative_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_creative_template(project_id, id, update_creative_template_request, opts = {}) ⇒ CreativeTemplate
PATCH bumps ‘version` whenever the schema field is provided (per `API.md`  3.6 — schema changes are versioned but do not retroactively re-validate existing creatives).
228 229 230 231 |
# File 'lib/knievel/api/creative_templates_api.rb', line 228 def update_creative_template(project_id, id, update_creative_template_request, opts = {}) data, _status_code, _headers = update_creative_template_with_http_info(project_id, id, update_creative_template_request, opts) data end |
#update_creative_template_with_http_info(project_id, id, update_creative_template_request, opts = {}) ⇒ Array<(CreativeTemplate, Integer, Hash)>
PATCH bumps `version` whenever the schema field is provided (per `API.md`  3.6 — schema changes are versioned but do not retroactively re-validate existing creatives).
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/knievel/api/creative_templates_api.rb', line 239 def update_creative_template_with_http_info(project_id, id, update_creative_template_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CreativeTemplatesApi.update_creative_template ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling CreativeTemplatesApi.update_creative_template" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CreativeTemplatesApi.update_creative_template" end # verify the required parameter 'update_creative_template_request' is set if @api_client.config.client_side_validation && update_creative_template_request.nil? fail ArgumentError, "Missing the required parameter 'update_creative_template_request' when calling CreativeTemplatesApi.update_creative_template" end # resource path local_var_path = '/v1/projects/{project_id}/creative-templates/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_creative_template_request) # return_type return_type = opts[:debug_return_type] || 'CreativeTemplate' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"CreativeTemplatesApi.update_creative_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CreativeTemplatesApi#update_creative_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |