Class: Knievel::DecisionPlacement

Inherits:
ApiModelBase show all
Defined in:
lib/knievel/models/decision_placement.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DecisionPlacement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/knievel/models/decision_placement.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::DecisionPlacement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::DecisionPlacement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'site_id')
    self.site_id = attributes[:'site_id']
  end

  if attributes.key?(:'site_url')
    self.site_url = attributes[:'site_url']
  end

  if attributes.key?(:'site_external_id')
    self.site_external_id = attributes[:'site_external_id']
  end

  if attributes.key?(:'zone_ids')
    if (value = attributes[:'zone_ids']).is_a?(Array)
      self.zone_ids = value
    end
  end

  if attributes.key?(:'ad_types')
    if (value = attributes[:'ad_types']).is_a?(Array)
      self.ad_types = value
    end
  else
    self.ad_types = nil
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  end

  if attributes.key?(:'force')
    self.force = attributes[:'force']
  end
end

Instance Attribute Details

#ad_typesObject

Returns the value of attribute ad_types.



28
29
30
# File 'lib/knievel/models/decision_placement.rb', line 28

def ad_types
  @ad_types
end

#countObject

Returns the value of attribute count.



30
31
32
# File 'lib/knievel/models/decision_placement.rb', line 30

def count
  @count
end

#forceObject

Returns the value of attribute force.



32
33
34
# File 'lib/knievel/models/decision_placement.rb', line 32

def force
  @force
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/knievel/models/decision_placement.rb', line 18

def id
  @id
end

#site_external_idObject

Returns the value of attribute site_external_id.



24
25
26
# File 'lib/knievel/models/decision_placement.rb', line 24

def site_external_id
  @site_external_id
end

#site_idObject

Returns the value of attribute site_id.



20
21
22
# File 'lib/knievel/models/decision_placement.rb', line 20

def site_id
  @site_id
end

#site_urlObject

Returns the value of attribute site_url.



22
23
24
# File 'lib/knievel/models/decision_placement.rb', line 22

def site_url
  @site_url
end

#zone_idsObject

Returns the value of attribute zone_ids.



26
27
28
# File 'lib/knievel/models/decision_placement.rb', line 26

def zone_ids
  @zone_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/knievel/models/decision_placement.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/knievel/models/decision_placement.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/knievel/models/decision_placement.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'site_id' => :'site_id',
    :'site_url' => :'site_url',
    :'site_external_id' => :'site_external_id',
    :'zone_ids' => :'zone_ids',
    :'ad_types' => :'ad_types',
    :'count' => :'count',
    :'force' => :'force'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/knievel/models/decision_placement.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/knievel/models/decision_placement.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/knievel/models/decision_placement.rb', line 59

def self.openapi_types
  {
    :'id' => :'String',
    :'site_id' => :'Integer',
    :'site_url' => :'String',
    :'site_external_id' => :'String',
    :'zone_ids' => :'Array<Integer>',
    :'ad_types' => :'Array<Integer>',
    :'count' => :'Integer',
    :'force' => :'ForceOverride'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/knievel/models/decision_placement.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      site_id == o.site_id &&
      site_url == o.site_url &&
      site_external_id == o.site_external_id &&
      zone_ids == o.zone_ids &&
      ad_types == o.ad_types &&
      count == o.count &&
      force == o.force
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/knievel/models/decision_placement.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/knievel/models/decision_placement.rb', line 203

def hash
  [id, site_id, site_url, site_external_id, zone_ids, ad_types, count, force].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/knievel/models/decision_placement.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @ad_types.nil?
    invalid_properties.push('invalid value for "ad_types", ad_types cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/knievel/models/decision_placement.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
# File 'lib/knievel/models/decision_placement.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @ad_types.nil?
  true
end