Class: Knievel::Flight

Inherits:
ApiModelBase show all
Defined in:
lib/knievel/models/flight.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Flight

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/knievel/models/flight.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::Flight` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::Flight`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  else
    self.campaign_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'priority_id')
    self.priority_id = attributes[:'priority_id']
  else
    self.priority_id = nil
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'site_ids')
    if (value = attributes[:'site_ids']).is_a?(Array)
      self.site_ids = value
    end
  else
    self.site_ids = nil
  end

  if attributes.key?(:'zone_ids')
    if (value = attributes[:'zone_ids']).is_a?(Array)
      self.zone_ids = value
    end
  else
    self.zone_ids = nil
  end

  if attributes.key?(:'ad_types')
    if (value = attributes[:'ad_types']).is_a?(Array)
      self.ad_types = value
    end
  else
    self.ad_types = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end

  if attributes.key?(:'etag')
    self.etag = attributes[:'etag']
  else
    self.etag = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#ad_typesObject

Returns the value of attribute ad_types.



36
37
38
# File 'lib/knievel/models/flight.rb', line 36

def ad_types
  @ad_types
end

#campaign_idObject

Returns the value of attribute campaign_id.



22
23
24
# File 'lib/knievel/models/flight.rb', line 22

def campaign_id
  @campaign_id
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/knievel/models/flight.rb', line 42

def created_at
  @created_at
end

#end_dateObject

Returns the value of attribute end_date.



30
31
32
# File 'lib/knievel/models/flight.rb', line 30

def end_date
  @end_date
end

#etagObject

Returns the value of attribute etag.



40
41
42
# File 'lib/knievel/models/flight.rb', line 40

def etag
  @etag
end

#external_idObject

Returns the value of attribute external_id.



20
21
22
# File 'lib/knievel/models/flight.rb', line 20

def external_id
  @external_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/knievel/models/flight.rb', line 18

def id
  @id
end

#is_activeObject

Returns the value of attribute is_active.



38
39
40
# File 'lib/knievel/models/flight.rb', line 38

def is_active
  @is_active
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/knievel/models/flight.rb', line 24

def name
  @name
end

#priority_idObject

Returns the value of attribute priority_id.



26
27
28
# File 'lib/knievel/models/flight.rb', line 26

def priority_id
  @priority_id
end

#site_idsObject

Returns the value of attribute site_ids.



32
33
34
# File 'lib/knievel/models/flight.rb', line 32

def site_ids
  @site_ids
end

#start_dateObject

Returns the value of attribute start_date.



28
29
30
# File 'lib/knievel/models/flight.rb', line 28

def start_date
  @start_date
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/knievel/models/flight.rb', line 44

def updated_at
  @updated_at
end

#zone_idsObject

Returns the value of attribute zone_ids.



34
35
36
# File 'lib/knievel/models/flight.rb', line 34

def zone_ids
  @zone_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/knievel/models/flight.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/knievel/models/flight.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/knievel/models/flight.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'external_id' => :'external_id',
    :'campaign_id' => :'campaign_id',
    :'name' => :'name',
    :'priority_id' => :'priority_id',
    :'start_date' => :'start_date',
    :'end_date' => :'end_date',
    :'site_ids' => :'site_ids',
    :'zone_ids' => :'zone_ids',
    :'ad_types' => :'ad_types',
    :'is_active' => :'is_active',
    :'etag' => :'etag',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/knievel/models/flight.rb', line 419

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/knievel/models/flight.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/knievel/models/flight.rb', line 77

def self.openapi_types
  {
    :'id' => :'Integer',
    :'external_id' => :'String',
    :'campaign_id' => :'Integer',
    :'name' => :'String',
    :'priority_id' => :'Integer',
    :'start_date' => :'String',
    :'end_date' => :'String',
    :'site_ids' => :'Array<Integer>',
    :'zone_ids' => :'Array<Integer>',
    :'ad_types' => :'Array<Integer>',
    :'is_active' => :'Boolean',
    :'etag' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/knievel/models/flight.rb', line 385

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      external_id == o.external_id &&
      campaign_id == o.campaign_id &&
      name == o.name &&
      priority_id == o.priority_id &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      site_ids == o.site_ids &&
      zone_ids == o.zone_ids &&
      ad_types == o.ad_types &&
      is_active == o.is_active &&
      etag == o.etag &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


406
407
408
# File 'lib/knievel/models/flight.rb', line 406

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



412
413
414
# File 'lib/knievel/models/flight.rb', line 412

def hash
  [id, external_id, campaign_id, name, priority_id, start_date, end_date, site_ids, zone_ids, ad_types, is_active, etag, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/knievel/models/flight.rb', line 205

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @priority_id.nil?
    invalid_properties.push('invalid value for "priority_id", priority_id cannot be nil.')
  end

  if @site_ids.nil?
    invalid_properties.push('invalid value for "site_ids", site_ids cannot be nil.')
  end

  if @zone_ids.nil?
    invalid_properties.push('invalid value for "zone_ids", zone_ids cannot be nil.')
  end

  if @ad_types.nil?
    invalid_properties.push('invalid value for "ad_types", ad_types cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  if @etag.nil?
    invalid_properties.push('invalid value for "etag", etag cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/knievel/models/flight.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/knievel/models/flight.rb', line 257

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @campaign_id.nil?
  return false if @name.nil?
  return false if @priority_id.nil?
  return false if @site_ids.nil?
  return false if @zone_ids.nil?
  return false if @ad_types.nil?
  return false if @is_active.nil?
  return false if @etag.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end