Class: Knievel::SitesApi
- Inherits:
-
Object
- Object
- Knievel::SitesApi
- Defined in:
- lib/knievel/api/sites_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
- #batch_upsert_sites(project_id, batch_upsert_sites_request, opts = {}) ⇒ BatchUpsertSitesResult
-
#batch_upsert_sites_with_http_info(project_id, batch_upsert_sites_request, opts = {}) ⇒ Array<(BatchUpsertSitesResult, Integer, Hash)>
BatchUpsertSitesResult data, response status code and response headers.
- #create_site(project_id, create_site_request, opts = {}) ⇒ Site
-
#create_site_with_http_info(project_id, create_site_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Site data, response status code and response headers.
- #get_site(project_id, id, opts = {}) ⇒ Site
-
#get_site_with_http_info(project_id, id, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Site data, response status code and response headers.
-
#initialize(api_client = ApiClient.default) ⇒ SitesApi
constructor
A new instance of SitesApi.
- #list_sites(project_id, opts = {}) ⇒ SiteList
-
#list_sites_with_http_info(project_id, opts = {}) ⇒ Array<(SiteList, Integer, Hash)>
SiteList data, response status code and response headers.
- #update_site(project_id, id, update_site_request, opts = {}) ⇒ Site
-
#update_site_with_http_info(project_id, id, update_site_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Site data, response status code and response headers.
-
#upsert_site_by_url(project_id, upsert_site_by_url_request, opts = {}) ⇒ Site
Natural-key upsert.
-
#upsert_site_by_url_with_http_info(project_id, upsert_site_by_url_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Natural-key upsert.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/knievel/api/sites_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#batch_upsert_sites(project_id, batch_upsert_sites_request, opts = {}) ⇒ BatchUpsertSitesResult
26 27 28 29 |
# File 'lib/knievel/api/sites_api.rb', line 26 def batch_upsert_sites(project_id, batch_upsert_sites_request, opts = {}) data, _status_code, _headers = batch_upsert_sites_with_http_info(project_id, batch_upsert_sites_request, opts) data end |
#batch_upsert_sites_with_http_info(project_id, batch_upsert_sites_request, opts = {}) ⇒ Array<(BatchUpsertSitesResult, Integer, Hash)>
Returns BatchUpsertSitesResult data, response status code and response headers.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/knievel/api/sites_api.rb', line 35 def batch_upsert_sites_with_http_info(project_id, batch_upsert_sites_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.batch_upsert_sites ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.batch_upsert_sites" end # verify the required parameter 'batch_upsert_sites_request' is set if @api_client.config.client_side_validation && batch_upsert_sites_request.nil? fail ArgumentError, "Missing the required parameter 'batch_upsert_sites_request' when calling SitesApi.batch_upsert_sites" end # resource path local_var_path = '/v1/projects/{project_id}/sites:batchUpsert'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(batch_upsert_sites_request) # return_type return_type = opts[:debug_return_type] || 'BatchUpsertSitesResult' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.batch_upsert_sites", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#batch_upsert_sites\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_site(project_id, create_site_request, opts = {}) ⇒ Site
96 97 98 99 |
# File 'lib/knievel/api/sites_api.rb', line 96 def create_site(project_id, create_site_request, opts = {}) data, _status_code, _headers = create_site_with_http_info(project_id, create_site_request, opts) data end |
#create_site_with_http_info(project_id, create_site_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Returns Site data, response status code and response headers.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/knievel/api/sites_api.rb', line 105 def create_site_with_http_info(project_id, create_site_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.create_site ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.create_site" end # verify the required parameter 'create_site_request' is set if @api_client.config.client_side_validation && create_site_request.nil? fail ArgumentError, "Missing the required parameter 'create_site_request' when calling SitesApi.create_site" end # resource path local_var_path = '/v1/projects/{project_id}/sites'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_site_request) # return_type return_type = opts[:debug_return_type] || 'Site' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.create_site", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#create_site\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_site(project_id, id, opts = {}) ⇒ Site
166 167 168 169 |
# File 'lib/knievel/api/sites_api.rb', line 166 def get_site(project_id, id, opts = {}) data, _status_code, _headers = get_site_with_http_info(project_id, id, opts) data end |
#get_site_with_http_info(project_id, id, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Returns Site data, response status code and response headers.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/knievel/api/sites_api.rb', line 175 def get_site_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.get_site ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.get_site" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SitesApi.get_site" end # resource path local_var_path = '/v1/projects/{project_id}/sites/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Site' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.get_site", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#get_site\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_sites(project_id, opts = {}) ⇒ SiteList
232 233 234 235 |
# File 'lib/knievel/api/sites_api.rb', line 232 def list_sites(project_id, opts = {}) data, _status_code, _headers = list_sites_with_http_info(project_id, opts) data end |
#list_sites_with_http_info(project_id, opts = {}) ⇒ Array<(SiteList, Integer, Hash)>
Returns SiteList data, response status code and response headers.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/knievel/api/sites_api.rb', line 242 def list_sites_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.list_sites ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.list_sites" end # resource path local_var_path = '/v1/projects/{project_id}/sites'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SiteList' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.list_sites", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#list_sites\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_site(project_id, id, update_site_request, opts = {}) ⇒ Site
297 298 299 300 |
# File 'lib/knievel/api/sites_api.rb', line 297 def update_site(project_id, id, update_site_request, opts = {}) data, _status_code, _headers = update_site_with_http_info(project_id, id, update_site_request, opts) data end |
#update_site_with_http_info(project_id, id, update_site_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Returns Site data, response status code and response headers.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/knievel/api/sites_api.rb', line 307 def update_site_with_http_info(project_id, id, update_site_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.update_site ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.update_site" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SitesApi.update_site" end # verify the required parameter 'update_site_request' is set if @api_client.config.client_side_validation && update_site_request.nil? fail ArgumentError, "Missing the required parameter 'update_site_request' when calling SitesApi.update_site" end # resource path local_var_path = '/v1/projects/{project_id}/sites/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_site_request) # return_type return_type = opts[:debug_return_type] || 'Site' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.update_site", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#update_site\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upsert_site_by_url(project_id, upsert_site_by_url_request, opts = {}) ⇒ Site
Natural-key upsert. Returns the existing row (200) when a site with the same URL exists; otherwise creates (201). Per ‘API.md`  3.7: `:upsertByUrl` is the canonical entry point for URL-driven flows.
373 374 375 376 |
# File 'lib/knievel/api/sites_api.rb', line 373 def upsert_site_by_url(project_id, upsert_site_by_url_request, opts = {}) data, _status_code, _headers = upsert_site_by_url_with_http_info(project_id, upsert_site_by_url_request, opts) data end |
#upsert_site_by_url_with_http_info(project_id, upsert_site_by_url_request, opts = {}) ⇒ Array<(Site, Integer, Hash)>
Natural-key upsert. Returns the existing row (200) when a site with the same URL exists; otherwise creates (201). Per `API.md`  3.7: `:upsertByUrl` is the canonical entry point for URL-driven flows.
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/knievel/api/sites_api.rb', line 383 def upsert_site_by_url_with_http_info(project_id, upsert_site_by_url_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SitesApi.upsert_site_by_url ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling SitesApi.upsert_site_by_url" end # verify the required parameter 'upsert_site_by_url_request' is set if @api_client.config.client_side_validation && upsert_site_by_url_request.nil? fail ArgumentError, "Missing the required parameter 'upsert_site_by_url_request' when calling SitesApi.upsert_site_by_url" end # resource path local_var_path = '/v1/projects/{project_id}/sites:upsertByUrl'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(upsert_site_by_url_request) # return_type return_type = opts[:debug_return_type] || 'Site' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"SitesApi.upsert_site_by_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SitesApi#upsert_site_by_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |