Class: Knievel::TemplatedCreative
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::TemplatedCreative
- Defined in:
- lib/knievel/models/templated_creative.rb
Instance Attribute Summary collapse
-
#body ⇒ Object
The template’s Liquid source rendered against ‘values` plus the injected decision context (signed URLs, placement id, snapshot version) at decision time.
-
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
-
#template ⇒ Object
The referenced template’s name.
-
#values ⇒ Object
Echoed so callers can re-render or inspect.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TemplatedCreative
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TemplatedCreative
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/knievel/models/templated_creative.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::TemplatedCreative` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::TemplatedCreative`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'values') self.values = attributes[:'values'] else self.values = nil end if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'click_through_url') self.click_through_url = attributes[:'click_through_url'] end end |
Instance Attribute Details
#body ⇒ Object
The template’s Liquid source rendered against ‘values` plus the injected decision context (signed URLs, placement id, snapshot version) at decision time.
25 26 27 |
# File 'lib/knievel/models/templated_creative.rb', line 25 def body @body end |
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
27 28 29 |
# File 'lib/knievel/models/templated_creative.rb', line 27 def click_through_url @click_through_url end |
#template ⇒ Object
The referenced template’s name.
19 20 21 |
# File 'lib/knievel/models/templated_creative.rb', line 19 def template @template end |
#values ⇒ Object
Echoed so callers can re-render or inspect.
22 23 24 |
# File 'lib/knievel/models/templated_creative.rb', line 22 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/knievel/models/templated_creative.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/knievel/models/templated_creative.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/knievel/models/templated_creative.rb', line 30 def self.attribute_map { :'template' => :'template', :'values' => :'values', :'body' => :'body', :'click_through_url' => :'click_through_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/knievel/models/templated_creative.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 64 |
# File 'lib/knievel/models/templated_creative.rb', line 60 def self.openapi_nullable Set.new([ :'values', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/knievel/models/templated_creative.rb', line 50 def self.openapi_types { :'template' => :'String', :'values' => :'Object', :'body' => :'String', :'click_through_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 |
# File 'lib/knievel/models/templated_creative.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && template == o.template && values == o.values && body == o.body && click_through_url == o.click_through_url end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/knievel/models/templated_creative.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/knievel/models/templated_creative.rb', line 152 def hash [template, values, body, click_through_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 |
# File 'lib/knievel/models/templated_creative.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/knievel/models/templated_creative.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 |
# File 'lib/knievel/models/templated_creative.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @body.nil? true end |