Class: Knievel::TokensApi
- Inherits:
-
Object
- Object
- Knievel::TokensApi
- Defined in:
- lib/knievel/api/tokens_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_token(org_id, create_token_request, opts = {}) ⇒ CreateTokenResponse
Mint an opaque token.
-
#create_token_with_http_info(org_id, create_token_request, opts = {}) ⇒ Array<(CreateTokenResponse, Integer, Hash)>
Mint an opaque token.
-
#initialize(api_client = ApiClient.default) ⇒ TokensApi
constructor
A new instance of TokensApi.
-
#list_tokens(org_id, opts = {}) ⇒ TokenListResponse
List tokens (metadata only; secrets never leave the mint response).
-
#list_tokens_with_http_info(org_id, opts = {}) ⇒ Array<(TokenListResponse, Integer, Hash)>
List tokens (metadata only; secrets never leave the mint response).
-
#revoke_token(org_id, token_id, opts = {}) ⇒ nil
Revoke a token (soft delete via ‘revoked_at`).
-
#revoke_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a token (soft delete via `revoked_at`).
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/knievel/api/tokens_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_token(org_id, create_token_request, opts = {}) ⇒ CreateTokenResponse
Mint an opaque token. Returns the plaintext secret exactly once. Min role: org-admin.
27 28 29 30 |
# File 'lib/knievel/api/tokens_api.rb', line 27 def create_token(org_id, create_token_request, opts = {}) data, _status_code, _headers = create_token_with_http_info(org_id, create_token_request, opts) data end |
#create_token_with_http_info(org_id, create_token_request, opts = {}) ⇒ Array<(CreateTokenResponse, Integer, Hash)>
Mint an opaque token. Returns the plaintext secret exactly once. Min role: org-admin.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/knievel/api/tokens_api.rb', line 37 def create_token_with_http_info(org_id, create_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.create_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.create_token" end # verify the required parameter 'create_token_request' is set if @api_client.config.client_side_validation && create_token_request.nil? fail ArgumentError, "Missing the required parameter 'create_token_request' when calling TokensApi.create_token" end # resource path local_var_path = '/v1/orgs/{org_id}/tokens'.sub('{org_id}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json; charset=utf-8']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_token_request) # return_type return_type = opts[:debug_return_type] || 'CreateTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TokensApi.create_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#create_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_tokens(org_id, opts = {}) ⇒ TokenListResponse
List tokens (metadata only; secrets never leave the mint response). Min role: org-admin.
98 99 100 101 |
# File 'lib/knievel/api/tokens_api.rb', line 98 def list_tokens(org_id, opts = {}) data, _status_code, _headers = list_tokens_with_http_info(org_id, opts) data end |
#list_tokens_with_http_info(org_id, opts = {}) ⇒ Array<(TokenListResponse, Integer, Hash)>
List tokens (metadata only; secrets never leave the mint response). Min role: org-admin.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/knievel/api/tokens_api.rb', line 107 def list_tokens_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.list_tokens ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.list_tokens" end # resource path local_var_path = '/v1/orgs/{org_id}/tokens'.sub('{org_id}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TokensApi.list_tokens", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#list_tokens\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_token(org_id, token_id, opts = {}) ⇒ nil
Revoke a token (soft delete via ‘revoked_at`). The auth path filters revoked rows at the next request. Min role: org-admin.
160 161 162 163 |
# File 'lib/knievel/api/tokens_api.rb', line 160 def revoke_token(org_id, token_id, opts = {}) revoke_token_with_http_info(org_id, token_id, opts) nil end |
#revoke_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a token (soft delete via `revoked_at`). The auth path filters revoked rows at the next request. Min role: org-admin.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/knievel/api/tokens_api.rb', line 170 def revoke_token_with_http_info(org_id, token_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.revoke_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.revoke_token" end # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.revoke_token" end # resource path local_var_path = '/v1/orgs/{org_id}/tokens/{token_id}'.sub('{org_id}', CGI.escape(org_id.to_s)).sub('{token_id}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TokensApi.revoke_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#revoke_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |