Class: Knievel::UpdateAdLibraryItemRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::UpdateAdLibraryItemRequest
- Defined in:
- lib/knievel/models/update_ad_library_item_request.rb
Instance Attribute Summary collapse
-
#alt ⇒ Object
Returns the value of attribute alt.
-
#body ⇒ Object
Returns the value of attribute body.
-
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
-
#height ⇒ Object
Returns the value of attribute height.
-
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#width ⇒ Object
Returns the value of attribute width.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdLibraryItemRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdLibraryItemRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::UpdateAdLibraryItemRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::UpdateAdLibraryItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'alt') self.alt = attributes[:'alt'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'click_through_url') self.click_through_url = attributes[:'click_through_url'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#alt ⇒ Object
Returns the value of attribute alt.
26 27 28 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 26 def alt @alt end |
#body ⇒ Object
Returns the value of attribute body.
28 29 30 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 28 def body @body end |
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
30 31 32 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 30 def click_through_url @click_through_url end |
#height ⇒ Object
Returns the value of attribute height.
24 25 26 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 24 def height @height end |
#image_url ⇒ Object
Returns the value of attribute image_url.
20 21 22 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 20 def image_url @image_url end |
#is_active ⇒ Object
Returns the value of attribute is_active.
32 33 34 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 32 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 18 def name @name end |
#width ⇒ Object
Returns the value of attribute width.
22 23 24 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 22 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 35 def self.attribute_map { :'name' => :'name', :'image_url' => :'image_url', :'width' => :'width', :'height' => :'height', :'alt' => :'alt', :'body' => :'body', :'click_through_url' => :'click_through_url', :'is_active' => :'is_active' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 59 def self.openapi_types { :'name' => :'String', :'image_url' => :'String', :'width' => :'Integer', :'height' => :'Integer', :'alt' => :'String', :'body' => :'String', :'click_through_url' => :'String', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && image_url == o.image_url && width == o.width && height == o.height && alt == o.alt && body == o.body && click_through_url == o.click_through_url && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 165 def hash [name, image_url, width, height, alt, body, click_through_url, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/knievel/models/update_ad_library_item_request.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |