Class: Knievel::UpdateFlightRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::UpdateFlightRequest
- Defined in:
- lib/knievel/models/update_flight_request.rb
Instance Attribute Summary collapse
-
#ad_types ⇒ Object
Returns the value of attribute ad_types.
-
#end_date ⇒ Object
Returns the value of attribute end_date.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#priority_id ⇒ Object
Returns the value of attribute priority_id.
-
#site_ids ⇒ Object
Returns the value of attribute site_ids.
-
#start_date ⇒ Object
Returns the value of attribute start_date.
-
#zone_ids ⇒ Object
Returns the value of attribute zone_ids.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateFlightRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateFlightRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/knievel/models/update_flight_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::UpdateFlightRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::UpdateFlightRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'priority_id') self.priority_id = attributes[:'priority_id'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'site_ids') if (value = attributes[:'site_ids']).is_a?(Array) self.site_ids = value end end if attributes.key?(:'zone_ids') if (value = attributes[:'zone_ids']).is_a?(Array) self.zone_ids = value end end if attributes.key?(:'ad_types') if (value = attributes[:'ad_types']).is_a?(Array) self.ad_types = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#ad_types ⇒ Object
Returns the value of attribute ad_types.
30 31 32 |
# File 'lib/knievel/models/update_flight_request.rb', line 30 def ad_types @ad_types end |
#end_date ⇒ Object
Returns the value of attribute end_date.
24 25 26 |
# File 'lib/knievel/models/update_flight_request.rb', line 24 def end_date @end_date end |
#is_active ⇒ Object
Returns the value of attribute is_active.
32 33 34 |
# File 'lib/knievel/models/update_flight_request.rb', line 32 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/knievel/models/update_flight_request.rb', line 18 def name @name end |
#priority_id ⇒ Object
Returns the value of attribute priority_id.
20 21 22 |
# File 'lib/knievel/models/update_flight_request.rb', line 20 def priority_id @priority_id end |
#site_ids ⇒ Object
Returns the value of attribute site_ids.
26 27 28 |
# File 'lib/knievel/models/update_flight_request.rb', line 26 def site_ids @site_ids end |
#start_date ⇒ Object
Returns the value of attribute start_date.
22 23 24 |
# File 'lib/knievel/models/update_flight_request.rb', line 22 def start_date @start_date end |
#zone_ids ⇒ Object
Returns the value of attribute zone_ids.
28 29 30 |
# File 'lib/knievel/models/update_flight_request.rb', line 28 def zone_ids @zone_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/knievel/models/update_flight_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/knievel/models/update_flight_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/knievel/models/update_flight_request.rb', line 35 def self.attribute_map { :'name' => :'name', :'priority_id' => :'priority_id', :'start_date' => :'start_date', :'end_date' => :'end_date', :'site_ids' => :'site_ids', :'zone_ids' => :'zone_ids', :'ad_types' => :'ad_types', :'is_active' => :'is_active' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/knievel/models/update_flight_request.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/knievel/models/update_flight_request.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/knievel/models/update_flight_request.rb', line 59 def self.openapi_types { :'name' => :'String', :'priority_id' => :'Integer', :'start_date' => :'String', :'end_date' => :'String', :'site_ids' => :'Array<Integer>', :'zone_ids' => :'Array<Integer>', :'ad_types' => :'Array<Integer>', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/knievel/models/update_flight_request.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && priority_id == o.priority_id && start_date == o.start_date && end_date == o.end_date && site_ids == o.site_ids && zone_ids == o.zone_ids && ad_types == o.ad_types && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/knievel/models/update_flight_request.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/knievel/models/update_flight_request.rb', line 171 def hash [name, priority_id, start_date, end_date, site_ids, zone_ids, ad_types, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/knievel/models/update_flight_request.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/knievel/models/update_flight_request.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/knievel/models/update_flight_request.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |