Class: Knievel::Ad
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::Ad
- Defined in:
- lib/knievel/models/ad.rb
Instance Attribute Summary collapse
-
#ad_library_item_id ⇒ Object
Returns the value of attribute ad_library_item_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#creative_id ⇒ Object
Returns the value of attribute creative_id.
-
#etag ⇒ Object
Returns the value of attribute etag.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#flight_id ⇒ Object
Returns the value of attribute flight_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#weight ⇒ Object
Returns the value of attribute weight.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ad
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ad
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/knievel/models/ad.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::Ad` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::Ad`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'flight_id') self.flight_id = attributes[:'flight_id'] else self.flight_id = nil end if attributes.key?(:'creative_id') self.creative_id = attributes[:'creative_id'] end if attributes.key?(:'ad_library_item_id') self.ad_library_item_id = attributes[:'ad_library_item_id'] end if attributes.key?(:'weight') self.weight = attributes[:'weight'] else self.weight = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] else self.is_active = nil end if attributes.key?(:'etag') self.etag = attributes[:'etag'] else self.etag = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#ad_library_item_id ⇒ Object
Returns the value of attribute ad_library_item_id.
26 27 28 |
# File 'lib/knievel/models/ad.rb', line 26 def ad_library_item_id @ad_library_item_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/knievel/models/ad.rb', line 34 def created_at @created_at end |
#creative_id ⇒ Object
Returns the value of attribute creative_id.
24 25 26 |
# File 'lib/knievel/models/ad.rb', line 24 def creative_id @creative_id end |
#etag ⇒ Object
Returns the value of attribute etag.
32 33 34 |
# File 'lib/knievel/models/ad.rb', line 32 def etag @etag end |
#external_id ⇒ Object
Returns the value of attribute external_id.
20 21 22 |
# File 'lib/knievel/models/ad.rb', line 20 def external_id @external_id end |
#flight_id ⇒ Object
Returns the value of attribute flight_id.
22 23 24 |
# File 'lib/knievel/models/ad.rb', line 22 def flight_id @flight_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/knievel/models/ad.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
30 31 32 |
# File 'lib/knievel/models/ad.rb', line 30 def is_active @is_active end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/knievel/models/ad.rb', line 36 def updated_at @updated_at end |
#weight ⇒ Object
Returns the value of attribute weight.
28 29 30 |
# File 'lib/knievel/models/ad.rb', line 28 def weight @weight end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/knievel/models/ad.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/knievel/models/ad.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/knievel/models/ad.rb', line 39 def self.attribute_map { :'id' => :'id', :'external_id' => :'external_id', :'flight_id' => :'flight_id', :'creative_id' => :'creative_id', :'ad_library_item_id' => :'ad_library_item_id', :'weight' => :'weight', :'is_active' => :'is_active', :'etag' => :'etag', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/knievel/models/ad.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/knievel/models/ad.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/knievel/models/ad.rb', line 65 def self.openapi_types { :'id' => :'Integer', :'external_id' => :'String', :'flight_id' => :'Integer', :'creative_id' => :'Integer', :'ad_library_item_id' => :'String', :'weight' => :'Integer', :'is_active' => :'Boolean', :'etag' => :'String', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/knievel/models/ad.rb', line 279 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && external_id == o.external_id && flight_id == o.flight_id && creative_id == o.creative_id && ad_library_item_id == o.ad_library_item_id && weight == o.weight && is_active == o.is_active && etag == o.etag && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/knievel/models/ad.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/knievel/models/ad.rb', line 302 def hash [id, external_id, flight_id, creative_id, ad_library_item_id, weight, is_active, etag, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/knievel/models/ad.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @flight_id.nil? invalid_properties.push('invalid value for "flight_id", flight_id cannot be nil.') end if @weight.nil? invalid_properties.push('invalid value for "weight", weight cannot be nil.') end if @is_active.nil? invalid_properties.push('invalid value for "is_active", is_active cannot be nil.') end if @etag.nil? invalid_properties.push('invalid value for "etag", etag cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/knievel/models/ad.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/knievel/models/ad.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @flight_id.nil? return false if @weight.nil? return false if @is_active.nil? return false if @etag.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |