Class: Knievel::AdLibraryItem

Inherits:
ApiModelBase show all
Defined in:
lib/knievel/models/ad_library_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdLibraryItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/knievel/models/ad_library_item.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::AdLibraryItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::AdLibraryItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'alt')
    self.alt = attributes[:'alt']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'values')
    self.values = attributes[:'values']
  end

  if attributes.key?(:'click_through_url')
    self.click_through_url = attributes[:'click_through_url']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end

  if attributes.key?(:'etag')
    self.etag = attributes[:'etag']
  else
    self.etag = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#altObject

Returns the value of attribute alt.



32
33
34
# File 'lib/knievel/models/ad_library_item.rb', line 32

def alt
  @alt
end

#bodyObject

Returns the value of attribute body.



34
35
36
# File 'lib/knievel/models/ad_library_item.rb', line 34

def body
  @body
end

#click_through_urlObject

Returns the value of attribute click_through_url.



40
41
42
# File 'lib/knievel/models/ad_library_item.rb', line 40

def click_through_url
  @click_through_url
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/knievel/models/ad_library_item.rb', line 46

def created_at
  @created_at
end

#etagObject

Returns the value of attribute etag.



44
45
46
# File 'lib/knievel/models/ad_library_item.rb', line 44

def etag
  @etag
end

#external_idObject

Returns the value of attribute external_id.



20
21
22
# File 'lib/knievel/models/ad_library_item.rb', line 20

def external_id
  @external_id
end

#heightObject

Returns the value of attribute height.



30
31
32
# File 'lib/knievel/models/ad_library_item.rb', line 30

def height
  @height
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/knievel/models/ad_library_item.rb', line 18

def id
  @id
end

#image_urlObject

Returns the value of attribute image_url.



26
27
28
# File 'lib/knievel/models/ad_library_item.rb', line 26

def image_url
  @image_url
end

#is_activeObject

Returns the value of attribute is_active.



42
43
44
# File 'lib/knievel/models/ad_library_item.rb', line 42

def is_active
  @is_active
end

#kindObject

Returns the value of attribute kind.



24
25
26
# File 'lib/knievel/models/ad_library_item.rb', line 24

def kind
  @kind
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/knievel/models/ad_library_item.rb', line 22

def name
  @name
end

#template_idObject

Returns the value of attribute template_id.



36
37
38
# File 'lib/knievel/models/ad_library_item.rb', line 36

def template_id
  @template_id
end

#updated_atObject

Returns the value of attribute updated_at.



48
49
50
# File 'lib/knievel/models/ad_library_item.rb', line 48

def updated_at
  @updated_at
end

#valuesObject

Returns the value of attribute values.



38
39
40
# File 'lib/knievel/models/ad_library_item.rb', line 38

def values
  @values
end

#widthObject

Returns the value of attribute width.



28
29
30
# File 'lib/knievel/models/ad_library_item.rb', line 28

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/knievel/models/ad_library_item.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/knievel/models/ad_library_item.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/knievel/models/ad_library_item.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'external_id' => :'external_id',
    :'name' => :'name',
    :'kind' => :'kind',
    :'image_url' => :'image_url',
    :'width' => :'width',
    :'height' => :'height',
    :'alt' => :'alt',
    :'body' => :'body',
    :'template_id' => :'template_id',
    :'values' => :'values',
    :'click_through_url' => :'click_through_url',
    :'is_active' => :'is_active',
    :'etag' => :'etag',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/knievel/models/ad_library_item.rb', line 364

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
# File 'lib/knievel/models/ad_library_item.rb', line 105

def self.openapi_nullable
  Set.new([
    :'values',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/knievel/models/ad_library_item.rb', line 83

def self.openapi_types
  {
    :'id' => :'String',
    :'external_id' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'image_url' => :'String',
    :'width' => :'Integer',
    :'height' => :'Integer',
    :'alt' => :'String',
    :'body' => :'String',
    :'template_id' => :'Integer',
    :'values' => :'Object',
    :'click_through_url' => :'String',
    :'is_active' => :'Boolean',
    :'etag' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/knievel/models/ad_library_item.rb', line 328

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      external_id == o.external_id &&
      name == o.name &&
      kind == o.kind &&
      image_url == o.image_url &&
      width == o.width &&
      height == o.height &&
      alt == o.alt &&
      body == o.body &&
      template_id == o.template_id &&
      values == o.values &&
      click_through_url == o.click_through_url &&
      is_active == o.is_active &&
      etag == o.etag &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/knievel/models/ad_library_item.rb', line 351

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



357
358
359
# File 'lib/knievel/models/ad_library_item.rb', line 357

def hash
  [id, external_id, name, kind, image_url, width, height, alt, body, template_id, values, click_through_url, is_active, etag, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/knievel/models/ad_library_item.rb', line 208

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  if @etag.nil?
    invalid_properties.push('invalid value for "etag", etag cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/knievel/models/ad_library_item.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



244
245
246
247
248
249
250
251
252
253
254
# File 'lib/knievel/models/ad_library_item.rb', line 244

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @kind.nil?
  return false if @is_active.nil?
  return false if @etag.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end