Class: Knievel::CreateCreativeRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::CreateCreativeRequest
- Defined in:
- lib/knievel/models/create_creative_request.rb
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Object
Returns the value of attribute advertiser_id.
-
#alt ⇒ Object
Returns the value of attribute alt.
-
#body ⇒ Object
Returns the value of attribute body.
-
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#height ⇒ Object
Returns the value of attribute height.
-
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#kind ⇒ Object
"image", "html", or "native".
-
#name ⇒ Object
Returns the value of attribute name.
-
#template_id ⇒ Object
Returns the value of attribute template_id.
-
#values ⇒ Object
Returns the value of attribute values.
-
#width ⇒ Object
Returns the value of attribute width.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCreativeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCreativeRequest
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/knievel/models/create_creative_request.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::CreateCreativeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::CreateCreativeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'advertiser_id') self.advertiser_id = attributes[:'advertiser_id'] else self.advertiser_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'alt') self.alt = attributes[:'alt'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'values') self.values = attributes[:'values'] end if attributes.key?(:'click_through_url') self.click_through_url = attributes[:'click_through_url'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#advertiser_id ⇒ Object
Returns the value of attribute advertiser_id.
20 21 22 |
# File 'lib/knievel/models/create_creative_request.rb', line 20 def advertiser_id @advertiser_id end |
#alt ⇒ Object
Returns the value of attribute alt.
33 34 35 |
# File 'lib/knievel/models/create_creative_request.rb', line 33 def alt @alt end |
#body ⇒ Object
Returns the value of attribute body.
35 36 37 |
# File 'lib/knievel/models/create_creative_request.rb', line 35 def body @body end |
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
41 42 43 |
# File 'lib/knievel/models/create_creative_request.rb', line 41 def click_through_url @click_through_url end |
#external_id ⇒ Object
Returns the value of attribute external_id.
18 19 20 |
# File 'lib/knievel/models/create_creative_request.rb', line 18 def external_id @external_id end |
#height ⇒ Object
Returns the value of attribute height.
31 32 33 |
# File 'lib/knievel/models/create_creative_request.rb', line 31 def height @height end |
#image_url ⇒ Object
Returns the value of attribute image_url.
27 28 29 |
# File 'lib/knievel/models/create_creative_request.rb', line 27 def image_url @image_url end |
#is_active ⇒ Object
Returns the value of attribute is_active.
43 44 45 |
# File 'lib/knievel/models/create_creative_request.rb', line 43 def is_active @is_active end |
#kind ⇒ Object
"image", "html", or "native".
25 26 27 |
# File 'lib/knievel/models/create_creative_request.rb', line 25 def kind @kind end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/knievel/models/create_creative_request.rb', line 22 def name @name end |
#template_id ⇒ Object
Returns the value of attribute template_id.
37 38 39 |
# File 'lib/knievel/models/create_creative_request.rb', line 37 def template_id @template_id end |
#values ⇒ Object
Returns the value of attribute values.
39 40 41 |
# File 'lib/knievel/models/create_creative_request.rb', line 39 def values @values end |
#width ⇒ Object
Returns the value of attribute width.
29 30 31 |
# File 'lib/knievel/models/create_creative_request.rb', line 29 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/knievel/models/create_creative_request.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/knievel/models/create_creative_request.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/knievel/models/create_creative_request.rb', line 46 def self.attribute_map { :'external_id' => :'external_id', :'advertiser_id' => :'advertiser_id', :'name' => :'name', :'kind' => :'kind', :'image_url' => :'image_url', :'width' => :'width', :'height' => :'height', :'alt' => :'alt', :'body' => :'body', :'template_id' => :'template_id', :'values' => :'values', :'click_through_url' => :'click_through_url', :'is_active' => :'is_active' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/knievel/models/create_creative_request.rb', line 253 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 98 |
# File 'lib/knievel/models/create_creative_request.rb', line 94 def self.openapi_nullable Set.new([ :'values', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/knievel/models/create_creative_request.rb', line 75 def self.openapi_types { :'external_id' => :'String', :'advertiser_id' => :'Integer', :'name' => :'String', :'kind' => :'String', :'image_url' => :'String', :'width' => :'Integer', :'height' => :'Integer', :'alt' => :'String', :'body' => :'String', :'template_id' => :'Integer', :'values' => :'Object', :'click_through_url' => :'String', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/knievel/models/create_creative_request.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && external_id == o.external_id && advertiser_id == o.advertiser_id && name == o.name && kind == o.kind && image_url == o.image_url && width == o.width && height == o.height && alt == o.alt && body == o.body && template_id == o.template_id && values == o.values && click_through_url == o.click_through_url && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/knievel/models/create_creative_request.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/knievel/models/create_creative_request.rb', line 246 def hash [external_id, advertiser_id, name, kind, image_url, width, height, alt, body, template_id, values, click_through_url, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/knievel/models/create_creative_request.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @advertiser_id.nil? invalid_properties.push('invalid value for "advertiser_id", advertiser_id cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/knievel/models/create_creative_request.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 |
# File 'lib/knievel/models/create_creative_request.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @advertiser_id.nil? return false if @kind.nil? true end |