Class: Knievel::DecisionAd
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::DecisionAd
- Defined in:
- lib/knievel/models/decision_ad.rb
Instance Attribute Summary collapse
-
#ad_id ⇒ Object
Returns the value of attribute ad_id.
-
#advertiser_id ⇒ Object
Returns the value of attribute advertiser_id.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#click_url ⇒ Object
Returns the value of attribute click_url.
-
#creative_id ⇒ Object
Returns the value of attribute creative_id.
-
#flight_id ⇒ Object
Returns the value of attribute flight_id.
-
#impression_url ⇒ Object
Returns the value of attribute impression_url.
-
#priority_id ⇒ Object
Returns the value of attribute priority_id.
-
#site_id ⇒ Object
Returns the value of attribute site_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DecisionAd
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DecisionAd
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/knievel/models/decision_ad.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::DecisionAd` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::DecisionAd`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_id') self.ad_id = attributes[:'ad_id'] else self.ad_id = nil end if attributes.key?(:'creative_id') self.creative_id = attributes[:'creative_id'] else self.creative_id = nil end if attributes.key?(:'flight_id') self.flight_id = attributes[:'flight_id'] else self.flight_id = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] else self.campaign_id = nil end if attributes.key?(:'advertiser_id') self.advertiser_id = attributes[:'advertiser_id'] else self.advertiser_id = nil end if attributes.key?(:'priority_id') self.priority_id = attributes[:'priority_id'] else self.priority_id = nil end if attributes.key?(:'site_id') self.site_id = attributes[:'site_id'] else self.site_id = nil end if attributes.key?(:'click_url') self.click_url = attributes[:'click_url'] else self.click_url = nil end if attributes.key?(:'impression_url') self.impression_url = attributes[:'impression_url'] else self.impression_url = nil end end |
Instance Attribute Details
#ad_id ⇒ Object
Returns the value of attribute ad_id.
18 19 20 |
# File 'lib/knievel/models/decision_ad.rb', line 18 def ad_id @ad_id end |
#advertiser_id ⇒ Object
Returns the value of attribute advertiser_id.
26 27 28 |
# File 'lib/knievel/models/decision_ad.rb', line 26 def advertiser_id @advertiser_id end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
24 25 26 |
# File 'lib/knievel/models/decision_ad.rb', line 24 def campaign_id @campaign_id end |
#click_url ⇒ Object
Returns the value of attribute click_url.
32 33 34 |
# File 'lib/knievel/models/decision_ad.rb', line 32 def click_url @click_url end |
#creative_id ⇒ Object
Returns the value of attribute creative_id.
20 21 22 |
# File 'lib/knievel/models/decision_ad.rb', line 20 def creative_id @creative_id end |
#flight_id ⇒ Object
Returns the value of attribute flight_id.
22 23 24 |
# File 'lib/knievel/models/decision_ad.rb', line 22 def flight_id @flight_id end |
#impression_url ⇒ Object
Returns the value of attribute impression_url.
34 35 36 |
# File 'lib/knievel/models/decision_ad.rb', line 34 def impression_url @impression_url end |
#priority_id ⇒ Object
Returns the value of attribute priority_id.
28 29 30 |
# File 'lib/knievel/models/decision_ad.rb', line 28 def priority_id @priority_id end |
#site_id ⇒ Object
Returns the value of attribute site_id.
30 31 32 |
# File 'lib/knievel/models/decision_ad.rb', line 30 def site_id @site_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/knievel/models/decision_ad.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/knievel/models/decision_ad.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/knievel/models/decision_ad.rb', line 37 def self.attribute_map { :'ad_id' => :'ad_id', :'creative_id' => :'creative_id', :'flight_id' => :'flight_id', :'campaign_id' => :'campaign_id', :'advertiser_id' => :'advertiser_id', :'priority_id' => :'priority_id', :'site_id' => :'site_id', :'click_url' => :'click_url', :'impression_url' => :'impression_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/knievel/models/decision_ad.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/knievel/models/decision_ad.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/knievel/models/decision_ad.rb', line 62 def self.openapi_types { :'ad_id' => :'Integer', :'creative_id' => :'Integer', :'flight_id' => :'Integer', :'campaign_id' => :'Integer', :'advertiser_id' => :'Integer', :'priority_id' => :'Integer', :'site_id' => :'Integer', :'click_url' => :'String', :'impression_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/knievel/models/decision_ad.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && ad_id == o.ad_id && creative_id == o.creative_id && flight_id == o.flight_id && campaign_id == o.campaign_id && advertiser_id == o.advertiser_id && priority_id == o.priority_id && site_id == o.site_id && click_url == o.click_url && impression_url == o.impression_url end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/knievel/models/decision_ad.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/knievel/models/decision_ad.rb', line 327 def hash [ad_id, creative_id, flight_id, campaign_id, advertiser_id, priority_id, site_id, click_url, impression_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/knievel/models/decision_ad.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_id.nil? invalid_properties.push('invalid value for "ad_id", ad_id cannot be nil.') end if @creative_id.nil? invalid_properties.push('invalid value for "creative_id", creative_id cannot be nil.') end if @flight_id.nil? invalid_properties.push('invalid value for "flight_id", flight_id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @advertiser_id.nil? invalid_properties.push('invalid value for "advertiser_id", advertiser_id cannot be nil.') end if @priority_id.nil? invalid_properties.push('invalid value for "priority_id", priority_id cannot be nil.') end if @site_id.nil? invalid_properties.push('invalid value for "site_id", site_id cannot be nil.') end if @click_url.nil? invalid_properties.push('invalid value for "click_url", click_url cannot be nil.') end if @impression_url.nil? invalid_properties.push('invalid value for "impression_url", impression_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/knievel/models/decision_ad.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/knievel/models/decision_ad.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_id.nil? return false if @creative_id.nil? return false if @flight_id.nil? return false if @campaign_id.nil? return false if @advertiser_id.nil? return false if @priority_id.nil? return false if @site_id.nil? return false if @click_url.nil? return false if @impression_url.nil? true end |