Class: Knievel::DecisionCreativeImageCreative
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::DecisionCreativeImageCreative
- Defined in:
- lib/knievel/models/decision_creative_image_creative.rb
Overview
The decision response’s typed creative block — a discriminated union on ‘type` mirroring `API.md`  1 /  3.5. The four arms match the four creative `kind`s.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#alt ⇒ Object
Returns the value of attribute alt.
-
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
-
#height ⇒ Object
Returns the value of attribute height.
-
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#type ⇒ Object
Returns the value of attribute type.
-
#width ⇒ Object
Returns the value of attribute width.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DecisionCreativeImageCreative
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DecisionCreativeImageCreative
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::DecisionCreativeImageCreative` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::DecisionCreativeImageCreative`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'alt') self.alt = attributes[:'alt'] end if attributes.key?(:'click_through_url') self.click_through_url = attributes[:'click_through_url'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#alt ⇒ Object
Returns the value of attribute alt.
25 26 27 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 25 def alt @alt end |
#click_through_url ⇒ Object
Returns the value of attribute click_through_url.
27 28 29 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 27 def click_through_url @click_through_url end |
#height ⇒ Object
Returns the value of attribute height.
23 24 25 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 23 def height @height end |
#image_url ⇒ Object
Returns the value of attribute image_url.
19 20 21 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 19 def image_url @image_url end |
#type ⇒ Object
Returns the value of attribute type.
29 30 31 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 29 def type @type end |
#width ⇒ Object
Returns the value of attribute width.
21 22 23 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 21 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 54 def self.attribute_map { :'image_url' => :'image_url', :'width' => :'width', :'height' => :'height', :'alt' => :'alt', :'click_through_url' => :'click_through_url', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 203 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
94 95 96 97 98 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 94 def self.openapi_all_of [ :'ImageCreative' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 76 def self.openapi_types { :'image_url' => :'String', :'width' => :'Integer', :'height' => :'Integer', :'alt' => :'String', :'click_through_url' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && image_url == o.image_url && width == o.width && height == o.height && alt == o.alt && click_through_url == o.click_through_url && type == o.type end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 196 def hash [image_url, width, height, alt, click_through_url, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 |
# File 'lib/knievel/models/decision_creative_image_creative.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["image"]) return false unless type_validator.valid?(@type) true end |