Class: Knievel::TaxonomyApi
- Inherits:
-
Object
- Object
- Knievel::TaxonomyApi
- Defined in:
- lib/knievel/api/taxonomy_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
- #get_ad_type(project_id, id, opts = {}) ⇒ AdType
-
#get_ad_type_with_http_info(project_id, id, opts = {}) ⇒ Array<(AdType, Integer, Hash)>
AdType data, response status code and response headers.
- #get_channel(project_id, id, opts = {}) ⇒ Channel
-
#get_channel_with_http_info(project_id, id, opts = {}) ⇒ Array<(Channel, Integer, Hash)>
Channel data, response status code and response headers.
- #get_priority(project_id, id, opts = {}) ⇒ Priority
-
#get_priority_with_http_info(project_id, id, opts = {}) ⇒ Array<(Priority, Integer, Hash)>
Priority data, response status code and response headers.
-
#initialize(api_client = ApiClient.default) ⇒ TaxonomyApi
constructor
A new instance of TaxonomyApi.
- #list_ad_types(project_id, opts = {}) ⇒ AdTypeList
-
#list_ad_types_with_http_info(project_id, opts = {}) ⇒ Array<(AdTypeList, Integer, Hash)>
AdTypeList data, response status code and response headers.
- #list_channels(project_id, opts = {}) ⇒ ChannelList
-
#list_channels_with_http_info(project_id, opts = {}) ⇒ Array<(ChannelList, Integer, Hash)>
ChannelList data, response status code and response headers.
- #list_priorities(project_id, opts = {}) ⇒ PriorityList
-
#list_priorities_with_http_info(project_id, opts = {}) ⇒ Array<(PriorityList, Integer, Hash)>
PriorityList data, response status code and response headers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TaxonomyApi
Returns a new instance of TaxonomyApi.
19 20 21 |
# File 'lib/knievel/api/taxonomy_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/knievel/api/taxonomy_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_ad_type(project_id, id, opts = {}) ⇒ AdType
26 27 28 29 |
# File 'lib/knievel/api/taxonomy_api.rb', line 26 def get_ad_type(project_id, id, opts = {}) data, _status_code, _headers = get_ad_type_with_http_info(project_id, id, opts) data end |
#get_ad_type_with_http_info(project_id, id, opts = {}) ⇒ Array<(AdType, Integer, Hash)>
Returns AdType data, response status code and response headers.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/knievel/api/taxonomy_api.rb', line 35 def get_ad_type_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.get_ad_type ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.get_ad_type" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TaxonomyApi.get_ad_type" end # resource path local_var_path = '/v1/projects/{project_id}/ad-types/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AdType' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.get_ad_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#get_ad_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_channel(project_id, id, opts = {}) ⇒ Channel
91 92 93 94 |
# File 'lib/knievel/api/taxonomy_api.rb', line 91 def get_channel(project_id, id, opts = {}) data, _status_code, _headers = get_channel_with_http_info(project_id, id, opts) data end |
#get_channel_with_http_info(project_id, id, opts = {}) ⇒ Array<(Channel, Integer, Hash)>
Returns Channel data, response status code and response headers.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/knievel/api/taxonomy_api.rb', line 100 def get_channel_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.get_channel ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.get_channel" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TaxonomyApi.get_channel" end # resource path local_var_path = '/v1/projects/{project_id}/channels/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Channel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.get_channel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#get_channel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_priority(project_id, id, opts = {}) ⇒ Priority
156 157 158 159 |
# File 'lib/knievel/api/taxonomy_api.rb', line 156 def get_priority(project_id, id, opts = {}) data, _status_code, _headers = get_priority_with_http_info(project_id, id, opts) data end |
#get_priority_with_http_info(project_id, id, opts = {}) ⇒ Array<(Priority, Integer, Hash)>
Returns Priority data, response status code and response headers.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/knievel/api/taxonomy_api.rb', line 165 def get_priority_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.get_priority ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.get_priority" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TaxonomyApi.get_priority" end # resource path local_var_path = '/v1/projects/{project_id}/priorities/{id}'.sub('{project_id}', CGI.escape(project_id.to_s)).sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Priority' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.get_priority", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#get_priority\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_ad_types(project_id, opts = {}) ⇒ AdTypeList
220 221 222 223 |
# File 'lib/knievel/api/taxonomy_api.rb', line 220 def list_ad_types(project_id, opts = {}) data, _status_code, _headers = list_ad_types_with_http_info(project_id, opts) data end |
#list_ad_types_with_http_info(project_id, opts = {}) ⇒ Array<(AdTypeList, Integer, Hash)>
Returns AdTypeList data, response status code and response headers.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/knievel/api/taxonomy_api.rb', line 228 def list_ad_types_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.list_ad_types ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.list_ad_types" end # resource path local_var_path = '/v1/projects/{project_id}/ad-types'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AdTypeList' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.list_ad_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#list_ad_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_channels(project_id, opts = {}) ⇒ ChannelList
279 280 281 282 |
# File 'lib/knievel/api/taxonomy_api.rb', line 279 def list_channels(project_id, opts = {}) data, _status_code, _headers = list_channels_with_http_info(project_id, opts) data end |
#list_channels_with_http_info(project_id, opts = {}) ⇒ Array<(ChannelList, Integer, Hash)>
Returns ChannelList data, response status code and response headers.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/knievel/api/taxonomy_api.rb', line 287 def list_channels_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.list_channels ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.list_channels" end # resource path local_var_path = '/v1/projects/{project_id}/channels'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ChannelList' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.list_channels", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#list_channels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_priorities(project_id, opts = {}) ⇒ PriorityList
338 339 340 341 |
# File 'lib/knievel/api/taxonomy_api.rb', line 338 def list_priorities(project_id, opts = {}) data, _status_code, _headers = list_priorities_with_http_info(project_id, opts) data end |
#list_priorities_with_http_info(project_id, opts = {}) ⇒ Array<(PriorityList, Integer, Hash)>
Returns PriorityList data, response status code and response headers.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/knievel/api/taxonomy_api.rb', line 346 def list_priorities_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TaxonomyApi.list_priorities ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling TaxonomyApi.list_priorities" end # resource path local_var_path = '/v1/projects/{project_id}/priorities'.sub('{project_id}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json; charset=utf-8']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PriorityList' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"TaxonomyApi.list_priorities", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TaxonomyApi#list_priorities\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |