Class: Knievel::WhoamiResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Knievel::WhoamiResponse
- Defined in:
- lib/knievel/models/whoami_response.rb
Instance Attribute Summary collapse
-
#actor_id ⇒ Object
Opaque actor identifier; matches ‘audit_log.actor`.
-
#org_id ⇒ Object
Returns the value of attribute org_id.
-
#project_id ⇒ Object
Present only when ‘scope == "project"`.
-
#role ⇒ Object
One of ‘org-owner`, `org-admin`, `admin`, `editor`, `reader`.
-
#scope ⇒ Object
‘org` or `project`.
-
#token_type ⇒ Object
‘opaque` for `kvl_*` bearers; `jwt` for OIDC bearers.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WhoamiResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WhoamiResponse
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/knievel/models/whoami_response.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Knievel::WhoamiResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Knievel::WhoamiResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'scope') self.scope = attributes[:'scope'] else self.scope = nil end if attributes.key?(:'org_id') self.org_id = attributes[:'org_id'] else self.org_id = nil end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'token_type') self.token_type = attributes[:'token_type'] else self.token_type = nil end if attributes.key?(:'actor_id') self.actor_id = attributes[:'actor_id'] else self.actor_id = nil end end |
Instance Attribute Details
#actor_id ⇒ Object
Opaque actor identifier; matches ‘audit_log.actor`.
33 34 35 |
# File 'lib/knievel/models/whoami_response.rb', line 33 def actor_id @actor_id end |
#org_id ⇒ Object
Returns the value of attribute org_id.
21 22 23 |
# File 'lib/knievel/models/whoami_response.rb', line 21 def org_id @org_id end |
#project_id ⇒ Object
Present only when ‘scope == "project"`.
24 25 26 |
# File 'lib/knievel/models/whoami_response.rb', line 24 def project_id @project_id end |
#role ⇒ Object
One of ‘org-owner`, `org-admin`, `admin`, `editor`, `reader`.
27 28 29 |
# File 'lib/knievel/models/whoami_response.rb', line 27 def role @role end |
#scope ⇒ Object
‘org` or `project`.
19 20 21 |
# File 'lib/knievel/models/whoami_response.rb', line 19 def scope @scope end |
#token_type ⇒ Object
‘opaque` for `kvl_*` bearers; `jwt` for OIDC bearers.
30 31 32 |
# File 'lib/knievel/models/whoami_response.rb', line 30 def token_type @token_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/knievel/models/whoami_response.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/knievel/models/whoami_response.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/knievel/models/whoami_response.rb', line 36 def self.attribute_map { :'scope' => :'scope', :'org_id' => :'org_id', :'project_id' => :'project_id', :'role' => :'role', :'token_type' => :'token_type', :'actor_id' => :'actor_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/knievel/models/whoami_response.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 |
# File 'lib/knievel/models/whoami_response.rb', line 70 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/knievel/models/whoami_response.rb', line 58 def self.openapi_types { :'scope' => :'String', :'org_id' => :'String', :'project_id' => :'String', :'role' => :'String', :'token_type' => :'String', :'actor_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/knievel/models/whoami_response.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && scope == o.scope && org_id == o.org_id && project_id == o.project_id && role == o.role && token_type == o.token_type && actor_id == o.actor_id end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/knievel/models/whoami_response.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/knievel/models/whoami_response.rb', line 237 def hash [scope, org_id, project_id, role, token_type, actor_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/knievel/models/whoami_response.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @scope.nil? invalid_properties.push('invalid value for "scope", scope cannot be nil.') end if @org_id.nil? invalid_properties.push('invalid value for "org_id", org_id cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @token_type.nil? invalid_properties.push('invalid value for "token_type", token_type cannot be nil.') end if @actor_id.nil? invalid_properties.push('invalid value for "actor_id", actor_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/knievel/models/whoami_response.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 164 |
# File 'lib/knievel/models/whoami_response.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @scope.nil? return false if @org_id.nil? return false if @role.nil? return false if @token_type.nil? return false if @actor_id.nil? true end |